@@ -51,6 +51,7 @@ class IcingaMultiEditForm extends DirectorObjectForm
         $loader = new IcingaObjectFieldLoader($object);
         $loader->prepareElements($this);
         $loader->addFieldsToForm($this);
+        $this->varNameMap = $loader->getNameMap();
 
         if ($form = $this->relatedForm) {
             if ($form instanceof DirectorObjectForm) {
@@ -237,10 +238,6 @@ class IcingaMultiEditForm extends DirectorObjectForm
         $this->removeElement($key);
         $label = $element->getLabel();
 
-        if ($this->isCustomVar($key)) {
-            $this->varNameMap[$key] = $label;
-        }
-
         $group = $this->getDisplayGroupForElement($element);
         $description = $element->getDescription();
 
