@@ -4,15 +4,15 @@ namespace Icinga\Module\Director\Dashboard;
 
 class DataDashboard extends Dashboard
 {
-    protected $dashletNames = array(
-        'ImportSource',
-        'Sync',
+    protected $dashletNames = [
         'Datafield',
+        'DatafieldCategory',
         'Datalist',
-    );
+        'Customvar'
+    ];
 
     public function getTitle()
     {
-        return $this->translate('Do more with your data');
+        return $this->translate('Do more with custom data');
     }
 }
