@@ -2,7 +2,6 @@
 
 namespace Icinga\Module\Director\Hook;
 
-use Icinga\Application\Logger;
 use Icinga\Module\Director\Db;
 use Icinga\Module\Director\Objects\DirectorJob;
 use Icinga\Module\Director\Web\Form\QuickForm;
@@ -53,6 +52,11 @@ abstract class JobHook
         return $class;
     }
 
+    public function exportSettings()
+    {
+        return $this->jobDefinition->getSettings();
+    }
+
     public static function getSuggestedRunInterval(QuickForm $form)
     {
         return 900;
@@ -79,30 +83,4 @@ abstract class JobHook
     {
         return $this->db;
     }
-
-    /**
-     * printf helper method
-     *
-     * @param  string $message Format string
-     * @param  mixed  ...$arg  Format string argument
-     *
-     * @return self
-     */
-    protected function info($message)
-    {
-        call_user_func_array(array('Icinga\\Application\\Logger', 'info'), func_get_args());
-        return $this;
-    }
-
-    protected function warning($message)
-    {
-        call_user_func_array(array('Icinga\\Application\\Logger', 'warn'), func_get_args());
-        return $this;
-    }
-
-    protected function error($message)
-    {
-        call_user_func_array(array('Icinga\\Application\\Logger', 'error'), func_get_args());
-        return $this;
-    }
 }
