@@ -2,17 +2,16 @@
 
 namespace Icinga\Module\Director\Objects;
 
-use Icinga\Module\Director\Data\Db\DbObject;
-
-class IcingaCommandField extends DbObject
+class IcingaCommandField extends IcingaObjectField
 {
     protected $keyName = array('command_id', 'datafield_id');
 
     protected $table = 'icinga_command_field';
 
     protected $defaultProperties = array(
-        'command_id'    => null,
-        'datafield_id'  => null,
-        'is_required'   => null
+        'command_id'   => null,
+        'datafield_id' => null,
+        'is_required'  => null,
+        'var_filter'   => null,
     );
 }
