@@ -174,7 +174,8 @@ abstract class ObjectController extends ActionController
         $this->tabs()->activate('modify');
         $this->addObjectTitle();
         // Hint: Service Sets are 'templates' (as long as not being assigned to a host
-        if ($this->getTableName() !== 'icinga_service_set'
+        if (
+            $this->getTableName() !== 'icinga_service_set'
             && $object->isTemplate()
             && $this->showNotInBranch($this->translate('Modifying Templates'))
         ) {
@@ -217,12 +218,14 @@ abstract class ObjectController extends ActionController
         $this->addTitle($this->translate('Clone: %s'), $object->getObjectName())
             ->addBackToObjectLink();
 
-        if ($object->isTemplate() && $this->showNotInBranch($this->translate('Cloning Templates'))) {
-            return;
-        }
+        if (! $object instanceof IcingaServiceSet) {
+            if ($object->isTemplate() && $this->showNotInBranch($this->translate('Cloning Templates'))) {
+                return;
+            }
 
-        if ($object->isTemplate() && $this->showNotInBranch($this->translate('Cloning Apply Rules'))) {
-            return;
+            if ($object->isTemplate() && $this->showNotInBranch($this->translate('Cloning Apply Rules'))) {
+                return;
+            }
         }
 
         $form = IcingaCloneObjectForm::load()
@@ -460,7 +463,8 @@ abstract class ObjectController extends ActionController
 
     protected function redirectToPreviewForExternals()
     {
-        if ($this->object
+        if (
+            $this->object
             && $this->object->isExternal()
             && ! in_array($this->object->getShortTableName(), $this->allowedExternals)
         ) {
@@ -566,7 +570,8 @@ abstract class ObjectController extends ActionController
         }
         if ($showHint) {
             $hasPreferredBranch = $this->hasPreferredBranch();
-            if (($hasPreferredBranch || $branch->isBranch())
+            if (
+                ($hasPreferredBranch || $branch->isBranch())
                 && $object->isObject()
                 && ! $this->getRequest()->isApiRequest()
             ) {
