@@ -2,10 +2,15 @@
 
 namespace Icinga\Module\Director\Web\Table;
 
+use GuzzleHttp\Psr7\ServerRequest;
 use Icinga\Module\Director\Objects\SyncRule;
 use gipfl\IcingaWeb2\Link;
 use gipfl\IcingaWeb2\Table\Extension\ZfSortablePriority;
 use gipfl\IcingaWeb2\Table\ZfQueryBasedTable;
+use Icinga\Module\Director\Web\Form\PropertyTableSortForm;
+use Icinga\Module\Director\Web\Form\QuickForm;
+use ipl\Html\Form;
+use ipl\Html\HtmlString;
 
 class SyncpropertyTable extends ZfQueryBasedTable
 {
@@ -33,7 +38,20 @@ class SyncpropertyTable extends ZfQueryBasedTable
 
     public function render()
     {
-        return $this->renderWithSortableForm();
+        if ($this->request === null) {
+            return parent::render();
+        }
+
+        return (new PropertyTableSortForm($this->getUniqueFormName(), new HtmlString(parent::render())))
+            ->setAction($this->request->getUrl()->getAbsoluteUrl())
+            ->on(Form::ON_SENT, function (PropertyTableSortForm $form) {
+                $csrf = $form->getElement(QuickForm::CSRF);
+                if ($csrf !== null && $csrf->isValid()) {
+                    $this->reallyHandleSortPriorityActions();
+                }
+            })
+            ->handleRequest(ServerRequest::fromGlobals())
+            ->render();
     }
 
     public function renderRow($row)
