@@ -5,6 +5,7 @@ namespace Icinga\Module\Director\Web\Tabs;
 use Icinga\Authentication\Auth;
 use gipfl\Translation\TranslationHelper;
 use gipfl\IcingaWeb2\Widget\Tabs;
+use Icinga\Module\Director\Auth\Permission;
 
 class InfraTabs extends Tabs
 {
@@ -24,21 +25,21 @@ class InfraTabs extends Tabs
     {
         $auth = $this->auth;
 
-        if ($auth->hasPermission('director/audit')) {
+        if ($auth->hasPermission(Permission::AUDIT)) {
             $this->add('activitylog', [
                 'label' => $this->translate('Activity Log'),
                 'url'   => 'director/config/activities'
             ]);
         }
 
-        if ($auth->hasPermission('director/deploy')) {
+        if ($auth->hasPermission(Permission::DEPLOY)) {
             $this->add('deploymentlog', [
                 'label' => $this->translate('Deployments'),
                 'url' => 'director/config/deployments'
             ]);
         }
 
-        if ($auth->hasPermission('director/admin')) {
+        if ($auth->hasPermission(Permission::ADMIN)) {
             $this->add('infrastructure', [
                 'label'     => $this->translate('Infrastructure'),
                 'url'       => 'director/dashboard',
