@@ -12,11 +12,12 @@ use Icinga\Module\Director\Test\BaseTestCase;
 
 class HostGroupMembershipResolverTest extends BaseTestCase
 {
-    const PREFIX = '__groupmembership';
-    const TYPE = 'host';
+    public const PREFIX = '__groupmembership';
+    public const TYPE = 'host';
 
-    public function setUp()
+    public function setUp(): void
     {
+        parent::setUp();
         IcingaTemplateRepository::clear();
     }
 
@@ -32,12 +33,12 @@ class HostGroupMembershipResolverTest extends BaseTestCase
         $db->delete('icinga_' . self::TYPE, $where);
     }
 
-    public static function setUpBeforeClass()
+    public static function setUpBeforeClass(): void
     {
         static::cleanArtifacts();
     }
 
-    public static function tearDownAfterClass()
+    public static function tearDownAfterClass(): void
     {
         static::cleanArtifacts();
     }
